ScalableMaskedSubFOperation

Struct ScalableMaskedSubFOperation 

pub struct ScalableMaskedSubFOperation<'c> { /* private fields */ }
A masked.subf operation. Masked subtraction for scalable vectors of floats.

The arm_sve.masked.subf operation takes one scalable vector mask and two scalable vector operands, and perform floating point subtraction on active lanes. Inactive lanes will keep the value of the first operand.

Implementations

Source

impl<'c> ScalableMaskedSubFOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> ScalableMaskedSubFOperationBuilder<'c, Unset, Unset, Unset, Unset>

Creates a builder.

pub fn res(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn mask(&self) -> Result<Value<'c, '_>, Error>

pub fn src_1(&self) -> Result<Value<'c, '_>, Error>

pub fn src_2(&self) -> Result<Value<'c, '_>, Error>